import { useState, useEffect } from 'react';
import { csv, timeParse } from 'd3';
//import { group } from 'd3-array';

//const csvUrl =
//  'https://gist.githubusercontent.com/MalempatiSaranya/45c9381a0cda8201fceb08b71d1fbfa1/raw/d825a095b227f8dc99ef4c497ba15a3d7869ee0d/covid.csv';

const csvUrl =
  'https://gist.githubusercontent.com/MalempatiSaranya/45c9381a0cda8201fceb08b71d1fbfa1/raw/d825a095b227f8dc99ef4c497ba15a3d7869ee0d/covid.csv';

const sum = (accumulator, currentValue) => accumulator + currentValue;

const parseDay = timeParse('%m/%d/%y');

const transform = rawData => {
  // Filter out rows that represent provinces or states.
  const countriesData = rawData.filter(d => !d['Province/State']);

  // Get timeseries data for each country.
  const days = rawData.columns.slice(4);
  return countriesData.map(d => {
    const countryName = d['Country/Region'];

    const countryTimeseries = days.map(day => ({
      date: parseDay(day),
      deathTotal: +d[day],
      countryName
    }));

    countryTimeseries.countryName = countryName;
    return countryTimeseries;
  });
};

export const useData = () => {
  const [data, setData] = useState();

  useEffect(() => {
    csv(csvUrl).then(rawData => {
      setData(transform(rawData));
    });
  }, []);

  return data;
};
